@@ -1,6 +1,10 @@
 package Lorem::Role::Style::HasText;
+{
+  $Lorem::Role::Style::HasText::VERSION = '0.200';
+}
 
 use Moose::Role;
+use MooseX::SemiAffordanceAccessor;
 
 use Lorem::Types qw(LoremStyleFontFamily LoremStyleFontStyle LoremStyleFontSize
 LoremStyleFontWeight LoremStyleFontVariant LoremStyleTextAlign LoremStyleTextAlign
