@@ -1,11 +1,14 @@
 package Lorem::Surface;
 {
-  $Lorem::Surface::VERSION = '0.23.1';
+  $Lorem::Surface::VERSION = '0.200';
 }
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 
+use Gtk2;
+
+
 
 1;
