@@ -1,6 +1,6 @@
 package Lorem::Util;
 {
-  $Lorem::Util::VERSION = '0.23.1';
+  $Lorem::Util::VERSION = '0.200';
 }
 use strict;
 use warnings;
@@ -8,20 +8,7 @@ use Carp 'confess';
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw( color2rgb in2pt pt2in escape_ampersand percent_of escape_entities escape_entity);
-
-use FindBin qw($Bin);
-
-use Convert::Color::X11;
-push @Convert::Color::X11::RGB_TXT, 'share/X11/rgb.txt';
-
-
-sub color2rgb {
-    my ( $in ) = @_;
-    my $color = Convert::Color::X11->new( $in );
-    no warnings;
-    $color->as_rgb16->rgb16;
-}
+our @EXPORT_OK = qw(in2pt pt2in escape_ampersand percent_of escape_entities escape_entity);
 
 sub in2pt {
     my $inches = shift;
